#
# pytest -v tests/dialogs/test_ruleseditor.py
#

import json
from PyQt5 import QtCore, QtWidgets, QtGui

from opensnitch.config import Config
from opensnitch.dialogs.ruleseditor import RulesEditorDialog

class TestRulesEditor():

    @classmethod
    def setup_method(self):
        white_icon = QtGui.QIcon("../res/icon-white.svg")
        self.rd = RulesEditorDialog(appicon=white_icon)
        self.rd.show()
        self.rd.ruleNameEdit.setText("xxx")
        self.rd.nodesCombo.addItem("unix:/tmp/osui.sock")
        self.rd.nodesCombo.setCurrentText("unix:/tmp/osui.sock")
        self.rd._nodes._nodes["unix:/tmp/osui.sock"] = {}

    def test_rule_no_fields(self, qtbot):
        """ Test that rules without fields selected cannot be created.
        """
        qtbot.addWidget(self.rd)

        def handle_dialog():
            qtbot.mouseClick(self.rd.buttonBox.button(QtWidgets.QDialogButtonBox.Apply), QtCore.Qt.LeftButton)
            qtbot.mouseClick(self.rd.buttonBox.button(QtWidgets.QDialogButtonBox.Close), QtCore.Qt.LeftButton)

        QtCore.QTimer.singleShot(100, handle_dialog)
        self.rd.exec_()
        assert self.rd.statusLabel.text() != ""

    def test_fields_empty(self, qtbot):
        """ Test that fields cannot be empty.
        """

        self.rd.pidCheck.setChecked(True)
        self.rd.pidLine.setText("")
        result, error = self.rd._save_rule()
        assert error != None

        self.rd.pidCheck.setChecked(False)
        self.rd.uidCheck.setChecked(True)
        self.rd.uidLine.setText("")
        result, error = self.rd._save_rule()
        assert error != None

        self.rd.uidCheck.setChecked(False)
        self.rd.procCheck.setChecked(True)
        self.rd.procLine.setText("")
        result, error = self.rd._save_rule()
        assert error != None

        self.rd.procCheck.setChecked(False)
        self.rd.cmdlineCheck.setChecked(True)
        self.rd.cmdlineLine.setText("")
        result, error = self.rd._save_rule()
        assert error != None

        self.rd.cmdlineCheck.setChecked(False)
        self.rd.dstPortCheck.setChecked(True)
        self.rd.dstPortLine.setText("")
        result, error = self.rd._save_rule()
        assert error != None

        self.rd.dstPortCheck.setChecked(False)
        self.rd.dstHostCheck.setChecked(True)
        self.rd.dstHostLine.setText("")
        result, error = self.rd._save_rule()
        assert error != None

        self.rd.dstHostCheck.setChecked(False)
        self.rd.dstListsCheck.setChecked(True)
        self.rd.dstListsLine.setText("")
        result, error = self.rd._save_rule()
        assert error != None

    def test_add_basic_rule(self, qtbot):
        """ Test adding a basic rule.
        """

        self.rd.statusLabel.setText("")
        self.rd.ruleNameEdit.setText("www.test.com")
        self.rd.dstHostCheck.setChecked(True)
        self.rd.dstHostLine.setText("www.test.com")
        self.rd.durationCombo.setCurrentIndex(self.rd._load_duration(Config.DURATION_UNTIL_RESTART))

        def handle_dialog():
            qtbot.mouseClick(self.rd.buttonBox.button(QtWidgets.QDialogButtonBox.Apply), QtCore.Qt.LeftButton)
            qtbot.mouseClick(self.rd.buttonBox.button(QtWidgets.QDialogButtonBox.Close), QtCore.Qt.LeftButton)

        QtCore.QTimer.singleShot(100, handle_dialog)
        self.rd.exec_()

        assert self.rd.statusLabel.text() == ""
        assert self.rd._db.get_rule("www.test.com", self.rd.nodesCombo.currentText()).next() == True
        assert self.rd._old_rule_name == "www.test.com"
        # after adding a rule, we enter into editing mode, to allow editing it
        # without closing the dialog.
        assert self.rd.WORK_MODE == self.rd.EDIT_RULE
        assert self.rd.rule.operator.type == Config.RULE_TYPE_SIMPLE
        assert self.rd.rule.operator.operand == "dest.host"
        assert self.rd.rule.operator.data == "www.test.com"
        assert self.rd.rule.duration == Config.DURATION_UNTIL_RESTART

    def test_add_complex_rule(self, qtbot):
        """ Test add complex rule.
        """
        self.rd.WORK_MODE = self.rd.ADD_RULE
        self.rd._reset_state()
        self.rd.statusLabel.setText("")
        self.rd.ruleNameEdit.setText("www.test-complex.com")
        self.rd.dstHostCheck.setChecked(True)
        self.rd.dstHostLine.setText("www.test-complex.com")
        self.rd.dstPortCheck.setChecked(True)
        self.rd.dstPortLine.setText("443")

        def handle_dialog():
            qtbot.mouseClick(self.rd.buttonBox.button(QtWidgets.QDialogButtonBox.Apply), QtCore.Qt.LeftButton)
            qtbot.mouseClick(self.rd.buttonBox.button(QtWidgets.QDialogButtonBox.Close), QtCore.Qt.LeftButton)

        QtCore.QTimer.singleShot(100, handle_dialog)
        self.rd.exec_()

        assert self.rd.statusLabel.text() == ""
        assert self.rd._db.get_rule("www.test-complex.com", self.rd.nodesCombo.currentText()).next() == True
        assert self.rd._old_rule_name == "www.test-complex.com"
        # after adding a rule, we enter into editing mode, to allow editing it
        # without closing the dialog.
        assert self.rd.WORK_MODE == self.rd.EDIT_RULE
        assert self.rd.rule.operator.type == Config.RULE_TYPE_LIST
        assert self.rd.rule.operator.operand == Config.RULE_TYPE_LIST
        json_rule = json.loads(self.rd.rule.operator.data)
        assert json_rule[0]['type'] == "simple"
        assert json_rule[0]['operand'] == "dest.port"
        assert json_rule[0]['data'] == "443"
        assert json_rule[1]['type'] == "simple"
        assert json_rule[1]['operand'] == "dest.host"
        assert json_rule[1]['data'] == "www.test-complex.com"

    def test_add_reject_rule(self, qtbot):
        """ Test adding new rule with action "reject".
        """

        self.rd.statusLabel.setText("")
        self.rd.ruleNameEdit.setText("www.test-reject.com")
        self.rd.dstHostCheck.setChecked(True)
        self.rd.dstHostLine.setText("www.test-reject.com")
        self.rd.actionRejectRadio.setChecked(True)

        def handle_dialog():
            qtbot.mouseClick(self.rd.buttonBox.button(QtWidgets.QDialogButtonBox.Apply), QtCore.Qt.LeftButton)
            qtbot.mouseClick(self.rd.buttonBox.button(QtWidgets.QDialogButtonBox.Close), QtCore.Qt.LeftButton)

        QtCore.QTimer.singleShot(100, handle_dialog)
        self.rd.exec_()

        assert self.rd.statusLabel.text() == ""
        assert self.rd._db.get_rule("www.test-reject.com", self.rd.nodesCombo.currentText()).next() == True
        assert self.rd._old_rule_name == "www.test-reject.com"
        # after adding a rule, we enter into editing mode, to allow editing it
        # without closing the dialog.
        assert self.rd.WORK_MODE == self.rd.EDIT_RULE
        assert self.rd.rule.operator.type == Config.RULE_TYPE_SIMPLE
        assert self.rd.rule.operator.operand == "dest.host"
        assert self.rd.rule.operator.data == "www.test-reject.com"
        assert self.rd.rule.action == Config.ACTION_REJECT

    def test_add_deny_rule(self, qtbot):
        """ Test adding new rule with action "deny".
        """

        self.rd.statusLabel.setText("")
        self.rd.ruleNameEdit.setText("www.test-deny.com")
        self.rd.dstHostCheck.setChecked(True)
        self.rd.dstHostLine.setText("www.test-deny.com")
        self.rd.actionDenyRadio.setChecked(True)

        def handle_dialog():
            qtbot.mouseClick(self.rd.buttonBox.button(QtWidgets.QDialogButtonBox.Apply), QtCore.Qt.LeftButton)
            qtbot.mouseClick(self.rd.buttonBox.button(QtWidgets.QDialogButtonBox.Close), QtCore.Qt.LeftButton)

        QtCore.QTimer.singleShot(100, handle_dialog)
        self.rd.exec_()

        assert self.rd.statusLabel.text() == ""
        assert self.rd._db.get_rule("www.test-deny.com", self.rd.nodesCombo.currentText()).next() == True
        assert self.rd._old_rule_name == "www.test-deny.com"
        # after adding a rule, we enter into editing mode, to allow editing it
        # without closing the dialog.
        assert self.rd.WORK_MODE == self.rd.EDIT_RULE
        assert self.rd.rule.operator.type == Config.RULE_TYPE_SIMPLE
        assert self.rd.rule.operator.operand == "dest.host"
        assert self.rd.rule.operator.data == "www.test-deny.com"
        assert self.rd.rule.action == Config.ACTION_DENY

    def test_add_allow_rule(self, qtbot):
        """ Test adding new rule with action "allow".
        """

        self.rd.statusLabel.setText("")
        self.rd.ruleNameEdit.setText("www.test-allow.com")
        self.rd.dstHostCheck.setChecked(True)
        self.rd.dstHostLine.setText("www.test-allow.com")
        self.rd.actionAllowRadio.setChecked(True)

        def handle_dialog():
            qtbot.mouseClick(self.rd.buttonBox.button(QtWidgets.QDialogButtonBox.Apply), QtCore.Qt.LeftButton)
            qtbot.mouseClick(self.rd.buttonBox.button(QtWidgets.QDialogButtonBox.Close), QtCore.Qt.LeftButton)

        QtCore.QTimer.singleShot(100, handle_dialog)
        self.rd.exec_()

        assert self.rd.statusLabel.text() == ""
        assert self.rd._db.get_rule("www.test-allow.com", self.rd.nodesCombo.currentText()).next() == True
        assert self.rd._old_rule_name == "www.test-allow.com"
        # after adding a rule, we enter into editing mode, to allow editing it
        # without closing the dialog.
        assert self.rd.WORK_MODE == self.rd.EDIT_RULE
        assert self.rd.rule.operator.type == Config.RULE_TYPE_SIMPLE
        assert self.rd.rule.operator.operand == "dest.host"
        assert self.rd.rule.operator.data == "www.test-allow.com"
        assert self.rd.rule.action == Config.ACTION_ALLOW

    def test_add_rule_name_conflict(self, qtbot):
        """ Test that rules with the same name cannot be added.
        """
        assert self.rd._db.get_rule("www.test.com", self.rd.nodesCombo.currentText()).next() == True

        self.rd.statusLabel.setText("")
        self.rd.ruleNameEdit.setText("www.test.com")
        self.rd.dstHostCheck.setChecked(True)
        self.rd.dstHostLine.setText("www.test.com")

        def handle_dialog():
            qtbot.mouseClick(self.rd.buttonBox.button(QtWidgets.QDialogButtonBox.Apply), QtCore.Qt.LeftButton)
            qtbot.mouseClick(self.rd.buttonBox.button(QtWidgets.QDialogButtonBox.Close), QtCore.Qt.LeftButton)

        QtCore.QTimer.singleShot(100, handle_dialog)
        self.rd.exec_()

        assert self.rd.statusLabel.text() != ""

    def test_load_rule(self, qtbot):
        """ Test loading a rule.
        """
        self.rd.WORK_MODE = self.rd.ADD_RULE
        self.rd._reset_state()
        records = self.rd._db.get_rule("www.test.com", self.rd.nodesCombo.currentText())
        assert records.next() == True

        self.rd.edit_rule(records, self.rd.nodesCombo.currentText())
        assert self.rd.WORK_MODE == self.rd.EDIT_RULE
        assert self.rd.ruleNameEdit.text() == "www.test.com"
        assert self.rd.dstHostCheck.isChecked() == True
        assert self.rd.dstHostLine.text() == "www.test.com"
        assert self.rd.durationCombo.currentIndex() == self.rd._load_duration(Config.DURATION_UNTIL_RESTART)

        def handle_dialog():
            qtbot.mouseClick(self.rd.buttonBox.button(QtWidgets.QDialogButtonBox.Close), QtCore.Qt.LeftButton)

        QtCore.QTimer.singleShot(100, handle_dialog)
        self.rd.exec_()

    def test_edit_and_rename_rule(self, qtbot):
        """ Test loading, editing and renaming a rule.
        """
        self.rd.WORK_MODE = self.rd.ADD_RULE
        self.rd._reset_state()
        records = self.rd._db.get_rule("www.test.com", self.rd.nodesCombo.currentText())
        assert records.next() == True

        self.rd.edit_rule(records, self.rd.nodesCombo.currentText())
        assert self.rd.WORK_MODE == self.rd.EDIT_RULE
        assert self.rd.ruleNameEdit.text() == "www.test.com"
        assert self.rd.dstHostCheck.isChecked() == True
        assert self.rd.dstHostLine.text() == "www.test.com"

        self.rd.ruleNameEdit.setText("www.test-renamed.com")
        self.rd.dstHostLine.setText("www.test-renamed.com")

        def handle_dialog():
            qtbot.mouseClick(self.rd.buttonBox.button(QtWidgets.QDialogButtonBox.Apply), QtCore.Qt.LeftButton)
            qtbot.mouseClick(self.rd.buttonBox.button(QtWidgets.QDialogButtonBox.Close), QtCore.Qt.LeftButton)

        QtCore.QTimer.singleShot(100, handle_dialog)
        self.rd.exec_()

        records = self.rd._db.get_rule("www.test.com", self.rd.nodesCombo.currentText())
        assert records.next() == False
        records = self.rd._db.get_rule("www.test-renamed.com", self.rd.nodesCombo.currentText())
        assert records.next() == True

    def test_durations(self, qtbot):
        """ Test adding new rule with action "deny".
        """

        self.rd.statusLabel.setText("")
        self.rd.ruleNameEdit.setText("www.test-duration.com")
        self.rd.dstHostCheck.setChecked(True)
        self.rd.dstHostLine.setText("www.test-duration.com")
        self.rd.actionDenyRadio.setChecked(True)
        self.rd.durationCombo.setCurrentIndex(self.rd._load_duration(Config.DURATION_ALWAYS))

        def handle_dialog():
            qtbot.mouseClick(self.rd.buttonBox.button(QtWidgets.QDialogButtonBox.Apply), QtCore.Qt.LeftButton)
            qtbot.mouseClick(self.rd.buttonBox.button(QtWidgets.QDialogButtonBox.Close), QtCore.Qt.LeftButton)

        QtCore.QTimer.singleShot(100, handle_dialog)
        self.rd.exec_()

        assert self.rd.statusLabel.text() == ""
        assert self.rd._db.get_rule("www.test-duration.com", self.rd.nodesCombo.currentText()).next() == True
        assert self.rd._old_rule_name == "www.test-duration.com"
        # after adding a rule, we enter into editing mode, to allow editing it
        # without closing the dialog.
        assert self.rd.WORK_MODE == self.rd.EDIT_RULE
        assert self.rd.rule.operator.type == Config.RULE_TYPE_SIMPLE
        assert self.rd.rule.operator.operand == "dest.host"
        assert self.rd.rule.operator.data == "www.test-duration.com"
        assert self.rd.rule.action == Config.ACTION_DENY
        assert self.rd.rule.duration == Config.DURATION_ALWAYS

    def test_rule_LANs(self, qtbot):
        """ Test rule with regexp and LAN keyword in particular.
        """
        self.rd.statusLabel.setText("")
        self.rd.ruleNameEdit.setText("www.test-rule-LAN.com")
        self.rd.dstIPCheck.setChecked(True)
        self.rd.dstIPCombo.setCurrentText(self.rd.LAN_LABEL)
        self.rd.actionDenyRadio.setChecked(True)
        self.rd.durationCombo.setCurrentIndex(self.rd._load_duration(Config.DURATION_ALWAYS))

        def handle_dialog():
            qtbot.mouseClick(self.rd.buttonBox.button(QtWidgets.QDialogButtonBox.Apply), QtCore.Qt.LeftButton)
            qtbot.mouseClick(self.rd.buttonBox.button(QtWidgets.QDialogButtonBox.Close), QtCore.Qt.LeftButton)

        QtCore.QTimer.singleShot(100, handle_dialog)
        self.rd.exec_()

        assert self.rd.statusLabel.text() == ""
        assert self.rd._db.get_rule("www.test-rule-LAN.com", self.rd.nodesCombo.currentText()).next() == True
        assert self.rd._old_rule_name == "www.test-rule-LAN.com"
        # after adding a rule, we enter into editing mode, to allow editing it
        # without closing the dialog.
        assert self.rd.WORK_MODE == self.rd.EDIT_RULE
        assert self.rd.rule.operator.type == Config.RULE_TYPE_REGEXP
        assert self.rd.rule.operator.operand == "dest.ip"
        assert self.rd.rule.operator.data == self.rd.LAN_RANGES
        assert self.rd.rule.action == Config.ACTION_DENY
        assert self.rd.rule.duration == Config.DURATION_ALWAYS

    def test_rule_networks(self, qtbot):
        """ Test rule with networks.
        """
        self.rd.statusLabel.setText("")
        self.rd.ruleNameEdit.setText("www.test-rule-networks.com")
        self.rd.dstIPCheck.setChecked(True)
        self.rd.dstIPCombo.setCurrentText("192.168.111.0/24")
        self.rd.actionDenyRadio.setChecked(True)
        self.rd.durationCombo.setCurrentIndex(self.rd._load_duration(Config.DURATION_ALWAYS))

        def handle_dialog():
            qtbot.mouseClick(self.rd.buttonBox.button(QtWidgets.QDialogButtonBox.Apply), QtCore.Qt.LeftButton)
            qtbot.mouseClick(self.rd.buttonBox.button(QtWidgets.QDialogButtonBox.Close), QtCore.Qt.LeftButton)

        QtCore.QTimer.singleShot(100, handle_dialog)
        self.rd.exec_()

        assert self.rd.statusLabel.text() == ""
        assert self.rd._db.get_rule("www.test-rule-networks.com", self.rd.nodesCombo.currentText()).next() == True
        assert self.rd._old_rule_name == "www.test-rule-networks.com"
        # after adding a rule, we enter into editing mode, to allow editing it
        # without closing the dialog.
        assert self.rd.WORK_MODE == self.rd.EDIT_RULE
        assert self.rd.rule.operator.type == Config.RULE_TYPE_NETWORK
        assert self.rd.rule.operator.operand == "dest.network"
        assert self.rd.rule.operator.data == "192.168.111.0/24"
        assert self.rd.rule.action == Config.ACTION_DENY
        assert self.rd.rule.duration == Config.DURATION_ALWAYS




from PyQt5 import QtCore
import os

from opensnitch.config import Config

DEFAULT_LANG = "en"
DEFAULT_LANGNAME = "English"

def __get_i18n_path():
    return os.path.dirname(os.path.realpath(__file__)) + "/../i18n"

def init(saved_lang):
    locale = QtCore.QLocale.system()
    lang = locale.name()
    if saved_lang:
        lang = saved_lang
    i18n_path = __get_i18n_path()
    print("Loading translations:", i18n_path, "locale:", lang)
    translator = QtCore.QTranslator()
    translator.load(i18n_path + "/" + lang + "/opensnitch-" + lang + ".qm")

    return translator

def save(cfg, lang):
    q = QtCore.QLocale(lang)
    langname = q.nativeLanguageName().capitalize()
    if lang == DEFAULT_LANG:
        langname = DEFAULT_LANGNAME
    cfg.setSettings(Config.DEFAULT_LANGUAGE, lang)
    cfg.setSettings(Config.DEFAULT_LANGNAME, langname)

def get_all():
    langs = [DEFAULT_LANG]
    names = [DEFAULT_LANGNAME]
    i18n_path = __get_i18n_path()
    lang_dirs = os.listdir(i18n_path)
    lang_dirs.sort()
    for lang in lang_dirs:
        q = QtCore.QLocale(lang)
        langs.append(lang)
        names.append(q.nativeLanguageName())
    return langs, names



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ui.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='ui.proto',
  package='protocol',
  syntax='proto3',
  serialized_options=_b('Z3github.com/evilsocket/opensnitch/daemon/ui/protocol'),
  serialized_pb=_b('\n\x08ui.proto\x12\x08protocol\"\xcb\x04\n\x05\x41lert\x12\n\n\x02id\x18\x01 \x01(\x04\x12\"\n\x04type\x18\x02 \x01(\x0e\x32\x14.protocol.Alert.Type\x12&\n\x06\x61\x63tion\x18\x03 \x01(\x0e\x32\x16.protocol.Alert.Action\x12*\n\x08priority\x18\x04 \x01(\x0e\x32\x18.protocol.Alert.Priority\x12\"\n\x04what\x18\x05 \x01(\x0e\x32\x14.protocol.Alert.What\x12\x0e\n\x04text\x18\x06 \x01(\tH\x00\x12!\n\x04proc\x18\x08 \x01(\x0b\x32\x11.protocol.ProcessH\x00\x12$\n\x04\x63onn\x18\t \x01(\x0b\x32\x14.protocol.ConnectionH\x00\x12\x1e\n\x04rule\x18\n \x01(\x0b\x32\x0e.protocol.RuleH\x00\x12\"\n\x06\x66wrule\x18\x0b \x01(\x0b\x32\x10.protocol.FwRuleH\x00\")\n\x08Priority\x12\x07\n\x03LOW\x10\x00\x12\n\n\x06MEDIUM\x10\x01\x12\x08\n\x04HIGH\x10\x02\"(\n\x04Type\x12\t\n\x05\x45RROR\x10\x00\x12\x0b\n\x07WARNING\x10\x01\x12\x08\n\x04INFO\x10\x02\"2\n\x06\x41\x63tion\x12\x08\n\x04NONE\x10\x00\x12\x0e\n\nSHOW_ALERT\x10\x01\x12\x0e\n\nSAVE_TO_DB\x10\x02\"l\n\x04What\x12\x0b\n\x07GENERIC\x10\x00\x12\x10\n\x0cPROC_MONITOR\x10\x01\x12\x0c\n\x08\x46IREWALL\x10\x02\x12\x0e\n\nCONNECTION\x10\x03\x12\x08\n\x04RULE\x10\x04\x12\x0b\n\x07NETLINK\x10\x05\x12\x10\n\x0cKERNEL_EVENT\x10\x06\x42\x06\n\x04\x64\x61ta\"\x19\n\x0bMsgResponse\x12\n\n\x02id\x18\x01 \x01(\x04\"o\n\x05\x45vent\x12\x0c\n\x04time\x18\x01 \x01(\t\x12(\n\nconnection\x18\x02 \x01(\x0b\x32\x14.protocol.Connection\x12\x1c\n\x04rule\x18\x03 \x01(\x0b\x32\x0e.protocol.Rule\x12\x10\n\x08unixnano\x18\x04 \x01(\x03\"\xd3\x06\n\nStatistics\x12\x16\n\x0e\x64\x61\x65mon_version\x18\x01 \x01(\t\x12\r\n\x05rules\x18\x02 \x01(\x04\x12\x0e\n\x06uptime\x18\x03 \x01(\x04\x12\x15\n\rdns_responses\x18\x04 \x01(\x04\x12\x13\n\x0b\x63onnections\x18\x05 \x01(\x04\x12\x0f\n\x07ignored\x18\x06 \x01(\x04\x12\x10\n\x08\x61\x63\x63\x65pted\x18\x07 \x01(\x04\x12\x0f\n\x07\x64ropped\x18\x08 \x01(\x04\x12\x11\n\trule_hits\x18\t \x01(\x04\x12\x13\n\x0brule_misses\x18\n \x01(\x04\x12\x33\n\x08\x62y_proto\x18\x0b \x03(\x0b\x32!.protocol.Statistics.ByProtoEntry\x12\x37\n\nby_address\x18\x0c \x03(\x0b\x32#.protocol.Statistics.ByAddressEntry\x12\x31\n\x07\x62y_host\x18\r \x03(\x0b\x32 .protocol.Statistics.ByHostEntry\x12\x31\n\x07\x62y_port\x18\x0e \x03(\x0b\x32 .protocol.Statistics.ByPortEntry\x12/\n\x06\x62y_uid\x18\x0f \x03(\x0b\x32\x1f.protocol.Statistics.ByUidEntry\x12=\n\rby_executable\x18\x10 \x03(\x0b\x32&.protocol.Statistics.ByExecutableEntry\x12\x1f\n\x06\x65vents\x18\x11 \x03(\x0b\x32\x0f.protocol.Event\x1a.\n\x0c\x42yProtoEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x04:\x02\x38\x01\x1a\x30\n\x0e\x42yAddressEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x04:\x02\x38\x01\x1a-\n\x0b\x42yHostEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x04:\x02\x38\x01\x1a-\n\x0b\x42yPortEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x04:\x02\x38\x01\x1a,\n\nByUidEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x04:\x02\x38\x01\x1a\x33\n\x11\x42yExecutableEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x04:\x02\x38\x01\">\n\x0bPingRequest\x12\n\n\x02id\x18\x01 \x01(\x04\x12#\n\x05stats\x18\x02 \x01(\x0b\x32\x14.protocol.Statistics\"\x17\n\tPingReply\x12\n\n\x02id\x18\x01 \x01(\x04\"\'\n\tStringInt\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\r\"\x9b\x03\n\x07Process\x12\x0b\n\x03pid\x18\x01 \x01(\x04\x12\x0c\n\x04ppid\x18\x02 \x01(\x04\x12\x0b\n\x03uid\x18\x03 \x01(\x04\x12\x0c\n\x04\x63omm\x18\x04 \x01(\t\x12\x0c\n\x04path\x18\x05 \x01(\t\x12\x0c\n\x04\x61rgs\x18\x06 \x03(\t\x12\'\n\x03\x65nv\x18\x07 \x03(\x0b\x32\x1a.protocol.Process.EnvEntry\x12\x0b\n\x03\x63wd\x18\x08 \x01(\t\x12\x33\n\tchecksums\x18\t \x03(\x0b\x32 .protocol.Process.ChecksumsEntry\x12\x10\n\x08io_reads\x18\n \x01(\x04\x12\x11\n\tio_writes\x18\x0b \x01(\x04\x12\x11\n\tnet_reads\x18\x0c \x01(\x04\x12\x12\n\nnet_writes\x18\r \x01(\x04\x12)\n\x0cprocess_tree\x18\x0e \x03(\x0b\x32\x13.protocol.StringInt\x1a*\n\x08\x45nvEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x30\n\x0e\x43hecksumsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xf3\x03\n\nConnection\x12\x10\n\x08protocol\x18\x01 \x01(\t\x12\x0e\n\x06src_ip\x18\x02 \x01(\t\x12\x10\n\x08src_port\x18\x03 \x01(\r\x12\x0e\n\x06\x64st_ip\x18\x04 \x01(\t\x12\x10\n\x08\x64st_host\x18\x05 \x01(\t\x12\x10\n\x08\x64st_port\x18\x06 \x01(\r\x12\x0f\n\x07user_id\x18\x07 \x01(\r\x12\x12\n\nprocess_id\x18\x08 \x01(\r\x12\x14\n\x0cprocess_path\x18\t \x01(\t\x12\x13\n\x0bprocess_cwd\x18\n \x01(\t\x12\x14\n\x0cprocess_args\x18\x0b \x03(\t\x12\x39\n\x0bprocess_env\x18\x0c \x03(\x0b\x32$.protocol.Connection.ProcessEnvEntry\x12\x45\n\x11process_checksums\x18\r \x03(\x0b\x32*.protocol.Connection.ProcessChecksumsEntry\x12)\n\x0cprocess_tree\x18\x0e \x03(\x0b\x32\x13.protocol.StringInt\x1a\x31\n\x0fProcessEnvEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x37\n\x15ProcessChecksumsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"l\n\x08Operator\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0f\n\x07operand\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\t\x12\x11\n\tsensitive\x18\x04 \x01(\x08\x12 \n\x04list\x18\x05 \x03(\x0b\x32\x12.protocol.Operator\"\xb6\x01\n\x04Rule\x12\x0f\n\x07\x63reated\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x04 \x01(\x08\x12\x12\n\nprecedence\x18\x05 \x01(\x08\x12\r\n\x05nolog\x18\x06 \x01(\x08\x12\x0e\n\x06\x61\x63tion\x18\x07 \x01(\t\x12\x10\n\x08\x64uration\x18\x08 \x01(\t\x12$\n\x08operator\x18\t \x01(\x0b\x32\x12.protocol.Operator\"-\n\x0fStatementValues\x12\x0b\n\x03Key\x18\x01 \x01(\t\x12\r\n\x05Value\x18\x02 \x01(\t\"P\n\tStatement\x12\n\n\x02Op\x18\x01 \x01(\t\x12\x0c\n\x04Name\x18\x02 \x01(\t\x12)\n\x06Values\x18\x03 \x03(\x0b\x32\x19.protocol.StatementValues\"5\n\x0b\x45xpressions\x12&\n\tStatement\x18\x01 \x01(\x0b\x32\x13.protocol.Statement\"\xd6\x01\n\x06\x46wRule\x12\r\n\x05Table\x18\x01 \x01(\t\x12\r\n\x05\x43hain\x18\x02 \x01(\t\x12\x0c\n\x04UUID\x18\x03 \x01(\t\x12\x0f\n\x07\x45nabled\x18\x04 \x01(\x08\x12\x10\n\x08Position\x18\x05 \x01(\x04\x12\x13\n\x0b\x44\x65scription\x18\x06 \x01(\t\x12\x12\n\nParameters\x18\x07 \x01(\t\x12*\n\x0b\x45xpressions\x18\x08 \x03(\x0b\x32\x15.protocol.Expressions\x12\x0e\n\x06Target\x18\t \x01(\t\x12\x18\n\x10TargetParameters\x18\n \x01(\t\"\x95\x01\n\x07\x46wChain\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\r\n\x05Table\x18\x02 \x01(\t\x12\x0e\n\x06\x46\x61mily\x18\x03 \x01(\t\x12\x10\n\x08Priority\x18\x04 \x01(\t\x12\x0c\n\x04Type\x18\x05 \x01(\t\x12\x0c\n\x04Hook\x18\x06 \x01(\t\x12\x0e\n\x06Policy\x18\x07 \x01(\t\x12\x1f\n\x05Rules\x18\x08 \x03(\x0b\x32\x10.protocol.FwRule\"M\n\x08\x46wChains\x12\x1e\n\x04Rule\x18\x01 \x01(\x0b\x32\x10.protocol.FwRule\x12!\n\x06\x43hains\x18\x02 \x03(\x0b\x32\x11.protocol.FwChain\"X\n\x0bSysFirewall\x12\x0f\n\x07\x45nabled\x18\x01 \x01(\x08\x12\x0f\n\x07Version\x18\x02 \x01(\r\x12\'\n\x0bSystemRules\x18\x03 \x03(\x0b\x32\x12.protocol.FwChains\"\xc4\x01\n\x0c\x43lientConfig\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\x12\x19\n\x11isFirewallRunning\x18\x04 \x01(\x08\x12\x0e\n\x06\x63onfig\x18\x05 \x01(\t\x12\x10\n\x08logLevel\x18\x06 \x01(\r\x12\x1d\n\x05rules\x18\x07 \x03(\x0b\x32\x0e.protocol.Rule\x12-\n\x0esystemFirewall\x18\x08 \x01(\x0b\x32\x15.protocol.SysFirewall\"\xbb\x01\n\x0cNotification\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x12\n\nclientName\x18\x02 \x01(\t\x12\x12\n\nserverName\x18\x03 \x01(\t\x12\x1e\n\x04type\x18\x04 \x01(\x0e\x32\x10.protocol.Action\x12\x0c\n\x04\x64\x61ta\x18\x05 \x01(\t\x12\x1d\n\x05rules\x18\x06 \x03(\x0b\x32\x0e.protocol.Rule\x12*\n\x0bsysFirewall\x18\x07 \x01(\x0b\x32\x15.protocol.SysFirewall\"\\\n\x11NotificationReply\x12\n\n\x02id\x18\x01 \x01(\x04\x12-\n\x04\x63ode\x18\x02 \x01(\x0e\x32\x1f.protocol.NotificationReplyCode\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\t*\x95\x02\n\x06\x41\x63tion\x12\x08\n\x04NONE\x10\x00\x12\x17\n\x13\x45NABLE_INTERCEPTION\x10\x01\x12\x18\n\x14\x44ISABLE_INTERCEPTION\x10\x02\x12\x13\n\x0f\x45NABLE_FIREWALL\x10\x03\x12\x14\n\x10\x44ISABLE_FIREWALL\x10\x04\x12\x13\n\x0fRELOAD_FW_RULES\x10\x05\x12\x11\n\rCHANGE_CONFIG\x10\x06\x12\x0f\n\x0b\x45NABLE_RULE\x10\x07\x12\x10\n\x0c\x44ISABLE_RULE\x10\x08\x12\x0f\n\x0b\x44\x45LETE_RULE\x10\t\x12\x0f\n\x0b\x43HANGE_RULE\x10\n\x12\r\n\tLOG_LEVEL\x10\x0b\x12\x08\n\x04STOP\x10\x0c\x12\x0e\n\nTASK_START\x10\r\x12\r\n\tTASK_STOP\x10\x0e**\n\x15NotificationReplyCode\x12\x06\n\x02OK\x10\x00\x12\t\n\x05\x45RROR\x10\x01\x32\xaf\x02\n\x02UI\x12\x34\n\x04Ping\x12\x15.protocol.PingRequest\x1a\x13.protocol.PingReply\"\x00\x12\x31\n\x07\x41skRule\x12\x14.protocol.Connection\x1a\x0e.protocol.Rule\"\x00\x12=\n\tSubscribe\x12\x16.protocol.ClientConfig\x1a\x16.protocol.ClientConfig\"\x00\x12J\n\rNotifications\x12\x1b.protocol.NotificationReply\x1a\x16.protocol.Notification\"\x00(\x01\x30\x01\x12\x35\n\tPostAlert\x12\x0f.protocol.Alert\x1a\x15.protocol.MsgResponse\"\x00\x42\x35Z3github.com/evilsocket/opensnitch/daemon/ui/protocolb\x06proto3')
)

_ACTION = _descriptor.EnumDescriptor(
  name='Action',
  full_name='protocol.Action',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ENABLE_INTERCEPTION', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DISABLE_INTERCEPTION', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ENABLE_FIREWALL', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DISABLE_FIREWALL', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RELOAD_FW_RULES', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHANGE_CONFIG', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ENABLE_RULE', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DISABLE_RULE', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DELETE_RULE', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHANGE_RULE', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOG_LEVEL', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STOP', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TASK_START', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TASK_STOP', index=14, number=14,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4153,
  serialized_end=4430,
)
_sym_db.RegisterEnumDescriptor(_ACTION)

Action = enum_type_wrapper.EnumTypeWrapper(_ACTION)
_NOTIFICATIONREPLYCODE = _descriptor.EnumDescriptor(
  name='NotificationReplyCode',
  full_name='protocol.NotificationReplyCode',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OK', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4432,
  serialized_end=4474,
)
_sym_db.RegisterEnumDescriptor(_NOTIFICATIONREPLYCODE)

NotificationReplyCode = enum_type_wrapper.EnumTypeWrapper(_NOTIFICATIONREPLYCODE)
NONE = 0
ENABLE_INTERCEPTION = 1
DISABLE_INTERCEPTION = 2
ENABLE_FIREWALL = 3
DISABLE_FIREWALL = 4
RELOAD_FW_RULES = 5
CHANGE_CONFIG = 6
ENABLE_RULE = 7
DISABLE_RULE = 8
DELETE_RULE = 9
CHANGE_RULE = 10
LOG_LEVEL = 11
STOP = 12
TASK_START = 13
TASK_STOP = 14
OK = 0
ERROR = 1


_ALERT_PRIORITY = _descriptor.EnumDescriptor(
  name='Priority',
  full_name='protocol.Alert.Priority',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LOW', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MEDIUM', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HIGH', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=357,
  serialized_end=398,
)
_sym_db.RegisterEnumDescriptor(_ALERT_PRIORITY)

_ALERT_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='protocol.Alert.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WARNING', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INFO', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=400,
  serialized_end=440,
)
_sym_db.RegisterEnumDescriptor(_ALERT_TYPE)

_ALERT_ACTION = _descriptor.EnumDescriptor(
  name='Action',
  full_name='protocol.Alert.Action',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NONE', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SHOW_ALERT', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SAVE_TO_DB', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=442,
  serialized_end=492,
)
_sym_db.RegisterEnumDescriptor(_ALERT_ACTION)

_ALERT_WHAT = _descriptor.EnumDescriptor(
  name='What',
  full_name='protocol.Alert.What',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GENERIC', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PROC_MONITOR', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FIREWALL', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONNECTION', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RULE', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NETLINK', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KERNEL_EVENT', index=6, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=494,
  serialized_end=602,
)
_sym_db.RegisterEnumDescriptor(_ALERT_WHAT)


_ALERT = _descriptor.Descriptor(
  name='Alert',
  full_name='protocol.Alert',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='protocol.Alert.id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='protocol.Alert.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='action', full_name='protocol.Alert.action', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='priority', full_name='protocol.Alert.priority', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='what', full_name='protocol.Alert.what', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text', full_name='protocol.Alert.text', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='proc', full_name='protocol.Alert.proc', index=6,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='conn', full_name='protocol.Alert.conn', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rule', full_name='protocol.Alert.rule', index=8,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fwrule', full_name='protocol.Alert.fwrule', index=9,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ALERT_PRIORITY,
    _ALERT_TYPE,
    _ALERT_ACTION,
    _ALERT_WHAT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='protocol.Alert.data',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=23,
  serialized_end=610,
)


_MSGRESPONSE = _descriptor.Descriptor(
  name='MsgResponse',
  full_name='protocol.MsgResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='protocol.MsgResponse.id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=612,
  serialized_end=637,
)


_EVENT = _descriptor.Descriptor(
  name='Event',
  full_name='protocol.Event',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='time', full_name='protocol.Event.time', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='connection', full_name='protocol.Event.connection', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rule', full_name='protocol.Event.rule', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='unixnano', full_name='protocol.Event.unixnano', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=639,
  serialized_end=750,
)


_STATISTICS_BYPROTOENTRY = _descriptor.Descriptor(
  name='ByProtoEntry',
  full_name='protocol.Statistics.ByProtoEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='protocol.Statistics.ByProtoEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='protocol.Statistics.ByProtoEntry.value', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1315,
  serialized_end=1361,
)

_STATISTICS_BYADDRESSENTRY = _descriptor.Descriptor(
  name='ByAddressEntry',
  full_name='protocol.Statistics.ByAddressEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='protocol.Statistics.ByAddressEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='protocol.Statistics.ByAddressEntry.value', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1363,
  serialized_end=1411,
)

_STATISTICS_BYHOSTENTRY = _descriptor.Descriptor(
  name='ByHostEntry',
  full_name='protocol.Statistics.ByHostEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='protocol.Statistics.ByHostEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='protocol.Statistics.ByHostEntry.value', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1413,
  serialized_end=1458,
)

_STATISTICS_BYPORTENTRY = _descriptor.Descriptor(
  name='ByPortEntry',
  full_name='protocol.Statistics.ByPortEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='protocol.Statistics.ByPortEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='protocol.Statistics.ByPortEntry.value', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1460,
  serialized_end=1505,
)

_STATISTICS_BYUIDENTRY = _descriptor.Descriptor(
  name='ByUidEntry',
  full_name='protocol.Statistics.ByUidEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='protocol.Statistics.ByUidEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='protocol.Statistics.ByUidEntry.value', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1507,
  serialized_end=1551,
)

_STATISTICS_BYEXECUTABLEENTRY = _descriptor.Descriptor(
  name='ByExecutableEntry',
  full_name='protocol.Statistics.ByExecutableEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='protocol.Statistics.ByExecutableEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='protocol.Statistics.ByExecutableEntry.value', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1553,
  serialized_end=1604,
)

_STATISTICS = _descriptor.Descriptor(
  name='Statistics',
  full_name='protocol.Statistics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='daemon_version', full_name='protocol.Statistics.daemon_version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rules', full_name='protocol.Statistics.rules', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uptime', full_name='protocol.Statistics.uptime', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dns_responses', full_name='protocol.Statistics.dns_responses', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='connections', full_name='protocol.Statistics.connections', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ignored', full_name='protocol.Statistics.ignored', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='accepted', full_name='protocol.Statistics.accepted', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dropped', full_name='protocol.Statistics.dropped', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rule_hits', full_name='protocol.Statistics.rule_hits', index=8,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rule_misses', full_name='protocol.Statistics.rule_misses', index=9,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='by_proto', full_name='protocol.Statistics.by_proto', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='by_address', full_name='protocol.Statistics.by_address', index=11,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='by_host', full_name='protocol.Statistics.by_host', index=12,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='by_port', full_name='protocol.Statistics.by_port', index=13,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='by_uid', full_name='protocol.Statistics.by_uid', index=14,
      number=15, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='by_executable', full_name='protocol.Statistics.by_executable', index=15,
      number=16, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='events', full_name='protocol.Statistics.events', index=16,
      number=17, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_STATISTICS_BYPROTOENTRY, _STATISTICS_BYADDRESSENTRY, _STATISTICS_BYHOSTENTRY, _STATISTICS_BYPORTENTRY, _STATISTICS_BYUIDENTRY, _STATISTICS_BYEXECUTABLEENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=753,
  serialized_end=1604,
)


_PINGREQUEST = _descriptor.Descriptor(
  name='PingRequest',
  full_name='protocol.PingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='protocol.PingRequest.id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stats', full_name='protocol.PingRequest.stats', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1606,
  serialized_end=1668,
)


_PINGREPLY = _descriptor.Descriptor(
  name='PingReply',
  full_name='protocol.PingReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='protocol.PingReply.id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1670,
  serialized_end=1693,
)


_STRINGINT = _descriptor.Descriptor(
  name='StringInt',
  full_name='protocol.StringInt',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='protocol.StringInt.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='protocol.StringInt.value', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1695,
  serialized_end=1734,
)


_PROCESS_ENVENTRY = _descriptor.Descriptor(
  name='EnvEntry',
  full_name='protocol.Process.EnvEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='protocol.Process.EnvEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='protocol.Process.EnvEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2056,
  serialized_end=2098,
)

_PROCESS_CHECKSUMSENTRY = _descriptor.Descriptor(
  name='ChecksumsEntry',
  full_name='protocol.Process.ChecksumsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='protocol.Process.ChecksumsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='protocol.Process.ChecksumsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2100,
  serialized_end=2148,
)

_PROCESS = _descriptor.Descriptor(
  name='Process',
  full_name='protocol.Process',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='pid', full_name='protocol.Process.pid', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ppid', full_name='protocol.Process.ppid', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uid', full_name='protocol.Process.uid', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='comm', full_name='protocol.Process.comm', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='path', full_name='protocol.Process.path', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='args', full_name='protocol.Process.args', index=5,
      number=6, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='env', full_name='protocol.Process.env', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cwd', full_name='protocol.Process.cwd', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='checksums', full_name='protocol.Process.checksums', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='io_reads', full_name='protocol.Process.io_reads', index=9,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='io_writes', full_name='protocol.Process.io_writes', index=10,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='net_reads', full_name='protocol.Process.net_reads', index=11,
      number=12, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='net_writes', full_name='protocol.Process.net_writes', index=12,
      number=13, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='process_tree', full_name='protocol.Process.process_tree', index=13,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_PROCESS_ENVENTRY, _PROCESS_CHECKSUMSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1737,
  serialized_end=2148,
)


_CONNECTION_PROCESSENVENTRY = _descriptor.Descriptor(
  name='ProcessEnvEntry',
  full_name='protocol.Connection.ProcessEnvEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='protocol.Connection.ProcessEnvEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='protocol.Connection.ProcessEnvEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2544,
  serialized_end=2593,
)

_CONNECTION_PROCESSCHECKSUMSENTRY = _descriptor.Descriptor(
  name='ProcessChecksumsEntry',
  full_name='protocol.Connection.ProcessChecksumsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='protocol.Connection.ProcessChecksumsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='protocol.Connection.ProcessChecksumsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2595,
  serialized_end=2650,
)

_CONNECTION = _descriptor.Descriptor(
  name='Connection',
  full_name='protocol.Connection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='protocol', full_name='protocol.Connection.protocol', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='src_ip', full_name='protocol.Connection.src_ip', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='src_port', full_name='protocol.Connection.src_port', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dst_ip', full_name='protocol.Connection.dst_ip', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dst_host', full_name='protocol.Connection.dst_host', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dst_port', full_name='protocol.Connection.dst_port', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_id', full_name='protocol.Connection.user_id', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='process_id', full_name='protocol.Connection.process_id', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='process_path', full_name='protocol.Connection.process_path', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='process_cwd', full_name='protocol.Connection.process_cwd', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='process_args', full_name='protocol.Connection.process_args', index=10,
      number=11, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='process_env', full_name='protocol.Connection.process_env', index=11,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='process_checksums', full_name='protocol.Connection.process_checksums', index=12,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='process_tree', full_name='protocol.Connection.process_tree', index=13,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CONNECTION_PROCESSENVENTRY, _CONNECTION_PROCESSCHECKSUMSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2151,
  serialized_end=2650,
)


_OPERATOR = _descriptor.Descriptor(
  name='Operator',
  full_name='protocol.Operator',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='protocol.Operator.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operand', full_name='protocol.Operator.operand', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='protocol.Operator.data', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sensitive', full_name='protocol.Operator.sensitive', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='list', full_name='protocol.Operator.list', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2652,
  serialized_end=2760,
)


_RULE = _descriptor.Descriptor(
  name='Rule',
  full_name='protocol.Rule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='created', full_name='protocol.Rule.created', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='protocol.Rule.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='protocol.Rule.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='protocol.Rule.enabled', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='precedence', full_name='protocol.Rule.precedence', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nolog', full_name='protocol.Rule.nolog', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='action', full_name='protocol.Rule.action', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duration', full_name='protocol.Rule.duration', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operator', full_name='protocol.Rule.operator', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2763,
  serialized_end=2945,
)


_STATEMENTVALUES = _descriptor.Descriptor(
  name='StatementValues',
  full_name='protocol.StatementValues',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='Key', full_name='protocol.StatementValues.Key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Value', full_name='protocol.StatementValues.Value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2947,
  serialized_end=2992,
)


_STATEMENT = _descriptor.Descriptor(
  name='Statement',
  full_name='protocol.Statement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='Op', full_name='protocol.Statement.Op', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Name', full_name='protocol.Statement.Name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Values', full_name='protocol.Statement.Values', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2994,
  serialized_end=3074,
)


_EXPRESSIONS = _descriptor.Descriptor(
  name='Expressions',
  full_name='protocol.Expressions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='Statement', full_name='protocol.Expressions.Statement', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3076,
  serialized_end=3129,
)


_FWRULE = _descriptor.Descriptor(
  name='FwRule',
  full_name='protocol.FwRule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='Table', full_name='protocol.FwRule.Table', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Chain', full_name='protocol.FwRule.Chain', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='UUID', full_name='protocol.FwRule.UUID', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Enabled', full_name='protocol.FwRule.Enabled', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Position', full_name='protocol.FwRule.Position', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Description', full_name='protocol.FwRule.Description', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Parameters', full_name='protocol.FwRule.Parameters', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Expressions', full_name='protocol.FwRule.Expressions', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Target', full_name='protocol.FwRule.Target', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='TargetParameters', full_name='protocol.FwRule.TargetParameters', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3132,
  serialized_end=3346,
)


_FWCHAIN = _descriptor.Descriptor(
  name='FwChain',
  full_name='protocol.FwChain',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='Name', full_name='protocol.FwChain.Name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Table', full_name='protocol.FwChain.Table', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Family', full_name='protocol.FwChain.Family', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Priority', full_name='protocol.FwChain.Priority', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Type', full_name='protocol.FwChain.Type', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Hook', full_name='protocol.FwChain.Hook', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Policy', full_name='protocol.FwChain.Policy', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Rules', full_name='protocol.FwChain.Rules', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3349,
  serialized_end=3498,
)


_FWCHAINS = _descriptor.Descriptor(
  name='FwChains',
  full_name='protocol.FwChains',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='Rule', full_name='protocol.FwChains.Rule', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Chains', full_name='protocol.FwChains.Chains', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3500,
  serialized_end=3577,
)


_SYSFIREWALL = _descriptor.Descriptor(
  name='SysFirewall',
  full_name='protocol.SysFirewall',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='Enabled', full_name='protocol.SysFirewall.Enabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='Version', full_name='protocol.SysFirewall.Version', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='SystemRules', full_name='protocol.SysFirewall.SystemRules', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3579,
  serialized_end=3667,
)


_CLIENTCONFIG = _descriptor.Descriptor(
  name='ClientConfig',
  full_name='protocol.ClientConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='protocol.ClientConfig.id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='protocol.ClientConfig.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='protocol.ClientConfig.version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='isFirewallRunning', full_name='protocol.ClientConfig.isFirewallRunning', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='protocol.ClientConfig.config', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='logLevel', full_name='protocol.ClientConfig.logLevel', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rules', full_name='protocol.ClientConfig.rules', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='systemFirewall', full_name='protocol.ClientConfig.systemFirewall', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3670,
  serialized_end=3866,
)


_NOTIFICATION = _descriptor.Descriptor(
  name='Notification',
  full_name='protocol.Notification',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='protocol.Notification.id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='clientName', full_name='protocol.Notification.clientName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serverName', full_name='protocol.Notification.serverName', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='protocol.Notification.type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='protocol.Notification.data', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rules', full_name='protocol.Notification.rules', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sysFirewall', full_name='protocol.Notification.sysFirewall', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3869,
  serialized_end=4056,
)


_NOTIFICATIONREPLY = _descriptor.Descriptor(
  name='NotificationReply',
  full_name='protocol.NotificationReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='protocol.NotificationReply.id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='code', full_name='protocol.NotificationReply.code', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='protocol.NotificationReply.data', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4058,
  serialized_end=4150,
)

_ALERT.fields_by_name['type'].enum_type = _ALERT_TYPE
_ALERT.fields_by_name['action'].enum_type = _ALERT_ACTION
_ALERT.fields_by_name['priority'].enum_type = _ALERT_PRIORITY
_ALERT.fields_by_name['what'].enum_type = _ALERT_WHAT
_ALERT.fields_by_name['proc'].message_type = _PROCESS
_ALERT.fields_by_name['conn'].message_type = _CONNECTION
_ALERT.fields_by_name['rule'].message_type = _RULE
_ALERT.fields_by_name['fwrule'].message_type = _FWRULE
_ALERT_PRIORITY.containing_type = _ALERT
_ALERT_TYPE.containing_type = _ALERT
_ALERT_ACTION.containing_type = _ALERT
_ALERT_WHAT.containing_type = _ALERT
_ALERT.oneofs_by_name['data'].fields.append(
  _ALERT.fields_by_name['text'])
_ALERT.fields_by_name['text'].containing_oneof = _ALERT.oneofs_by_name['data']
_ALERT.oneofs_by_name['data'].fields.append(
  _ALERT.fields_by_name['proc'])
_ALERT.fields_by_name['proc'].containing_oneof = _ALERT.oneofs_by_name['data']
_ALERT.oneofs_by_name['data'].fields.append(
  _ALERT.fields_by_name['conn'])
_ALERT.fields_by_name['conn'].containing_oneof = _ALERT.oneofs_by_name['data']
_ALERT.oneofs_by_name['data'].fields.append(
  _ALERT.fields_by_name['rule'])
_ALERT.fields_by_name['rule'].containing_oneof = _ALERT.oneofs_by_name['data']
_ALERT.oneofs_by_name['data'].fields.append(
  _ALERT.fields_by_name['fwrule'])
_ALERT.fields_by_name['fwrule'].containing_oneof = _ALERT.oneofs_by_name['data']
_EVENT.fields_by_name['connection'].message_type = _CONNECTION
_EVENT.fields_by_name['rule'].message_type = _RULE
_STATISTICS_BYPROTOENTRY.containing_type = _STATISTICS
_STATISTICS_BYADDRESSENTRY.containing_type = _STATISTICS
_STATISTICS_BYHOSTENTRY.containing_type = _STATISTICS
_STATISTICS_BYPORTENTRY.containing_type = _STATISTICS
_STATISTICS_BYUIDENTRY.containing_type = _STATISTICS
_STATISTICS_BYEXECUTABLEENTRY.containing_type = _STATISTICS
_STATISTICS.fields_by_name['by_proto'].message_type = _STATISTICS_BYPROTOENTRY
_STATISTICS.fields_by_name['by_address'].message_type = _STATISTICS_BYADDRESSENTRY
_STATISTICS.fields_by_name['by_host'].message_type = _STATISTICS_BYHOSTENTRY
_STATISTICS.fields_by_name['by_port'].message_type = _STATISTICS_BYPORTENTRY
_STATISTICS.fields_by_name['by_uid'].message_type = _STATISTICS_BYUIDENTRY
_STATISTICS.fields_by_name['by_executable'].message_type = _STATISTICS_BYEXECUTABLEENTRY
_STATISTICS.fields_by_name['events'].message_type = _EVENT
_PINGREQUEST.fields_by_name['stats'].message_type = _STATISTICS
_PROCESS_ENVENTRY.containing_type = _PROCESS
_PROCESS_CHECKSUMSENTRY.containing_type = _PROCESS
_PROCESS.fields_by_name['env'].message_type = _PROCESS_ENVENTRY
_PROCESS.fields_by_name['checksums'].message_type = _PROCESS_CHECKSUMSENTRY
_PROCESS.fields_by_name['process_tree'].message_type = _STRINGINT
_CONNECTION_PROCESSENVENTRY.containing_type = _CONNECTION
_CONNECTION_PROCESSCHECKSUMSENTRY.containing_type = _CONNECTION
_CONNECTION.fields_by_name['process_env'].message_type = _CONNECTION_PROCESSENVENTRY
_CONNECTION.fields_by_name['process_checksums'].message_type = _CONNECTION_PROCESSCHECKSUMSENTRY
_CONNECTION.fields_by_name['process_tree'].message_type = _STRINGINT
_OPERATOR.fields_by_name['list'].message_type = _OPERATOR
_RULE.fields_by_name['operator'].message_type = _OPERATOR
_STATEMENT.fields_by_name['Values'].message_type = _STATEMENTVALUES
_EXPRESSIONS.fields_by_name['Statement'].message_type = _STATEMENT
_FWRULE.fields_by_name['Expressions'].message_type = _EXPRESSIONS
_FWCHAIN.fields_by_name['Rules'].message_type = _FWRULE
_FWCHAINS.fields_by_name['Rule'].message_type = _FWRULE
_FWCHAINS.fields_by_name['Chains'].message_type = _FWCHAIN
_SYSFIREWALL.fields_by_name['SystemRules'].message_type = _FWCHAINS
_CLIENTCONFIG.fields_by_name['rules'].message_type = _RULE
_CLIENTCONFIG.fields_by_name['systemFirewall'].message_type = _SYSFIREWALL
_NOTIFICATION.fields_by_name['type'].enum_type = _ACTION
_NOTIFICATION.fields_by_name['rules'].message_type = _RULE
_NOTIFICATION.fields_by_name['sysFirewall'].message_type = _SYSFIREWALL
_NOTIFICATIONREPLY.fields_by_name['code'].enum_type = _NOTIFICATIONREPLYCODE
DESCRIPTOR.message_types_by_name['Alert'] = _ALERT
DESCRIPTOR.message_types_by_name['MsgResponse'] = _MSGRESPONSE
DESCRIPTOR.message_types_by_name['Event'] = _EVENT
DESCRIPTOR.message_types_by_name['Statistics'] = _STATISTICS
DESCRIPTOR.message_types_by_name['PingRequest'] = _PINGREQUEST
DESCRIPTOR.message_types_by_name['PingReply'] = _PINGREPLY
DESCRIPTOR.message_types_by_name['StringInt'] = _STRINGINT
DESCRIPTOR.message_types_by_name['Process'] = _PROCESS
DESCRIPTOR.message_types_by_name['Connection'] = _CONNECTION
DESCRIPTOR.message_types_by_name['Operator'] = _OPERATOR
DESCRIPTOR.message_types_by_name['Rule'] = _RULE
DESCRIPTOR.message_types_by_name['StatementValues'] = _STATEMENTVALUES
DESCRIPTOR.message_types_by_name['Statement'] = _STATEMENT
DESCRIPTOR.message_types_by_name['Expressions'] = _EXPRESSIONS
DESCRIPTOR.message_types_by_name['FwRule'] = _FWRULE
DESCRIPTOR.message_types_by_name['FwChain'] = _FWCHAIN
DESCRIPTOR.message_types_by_name['FwChains'] = _FWCHAINS
DESCRIPTOR.message_types_by_name['SysFirewall'] = _SYSFIREWALL
DESCRIPTOR.message_types_by_name['ClientConfig'] = _CLIENTCONFIG
DESCRIPTOR.message_types_by_name['Notification'] = _NOTIFICATION
DESCRIPTOR.message_types_by_name['NotificationReply'] = _NOTIFICATIONREPLY
DESCRIPTOR.enum_types_by_name['Action'] = _ACTION
DESCRIPTOR.enum_types_by_name['NotificationReplyCode'] = _NOTIFICATIONREPLYCODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Alert = _reflection.GeneratedProtocolMessageType('Alert', (_message.Message,), {
  'DESCRIPTOR' : _ALERT,
  '__module__' : 'ui_pb2'
  # @@protoc_insertion_point(class_scope:protocol.Alert)
  })
_sym_db.RegisterMessage(Alert)

MsgResponse = _reflection.GeneratedProtocolMessageType('MsgResponse', (_message.Message,), {
  'DESCRIPTOR' : _MSGRESPONSE,
  '__module__' : 'ui_pb2'
  # @@protoc_insertion_point(class_scope:protocol.MsgResponse)
  })
_sym_db.RegisterMessage(MsgResponse)

Event = _reflection.GeneratedProtocolMessageType('Event', (_message.Message,), {
  'DESCRIPTOR' : _EVENT,
  '__module__' : 'ui_pb2'
  # @@protoc_insertion_point(class_scope:protocol.Event)
  })
_sym_db.RegisterMessage(Event)

Statistics = _reflection.GeneratedProtocolMessageType('Statistics', (_message.Message,), {

  'ByProtoEntry' : _reflection.GeneratedProtocolMessageType('ByProtoEntry', (_message.Message,), {
    'DESCRIPTOR' : _STATISTICS_BYPROTOENTRY,
    '__module__' : 'ui_pb2'
    # @@protoc_insertion_point(class_scope:protocol.Statistics.ByProtoEntry)
    })
  ,

  'ByAddressEntry' : _reflection.GeneratedProtocolMessageType('ByAddressEntry', (_message.Message,), {
    'DESCRIPTOR' : _STATISTICS_BYADDRESSENTRY,
    '__module__' : 'ui_pb2'
    # @@protoc_insertion_point(class_scope:protocol.Statistics.ByAddressEntry)
    })
  ,

  'ByHostEntry' : _reflection.GeneratedProtocolMessageType('ByHostEntry', (_message.Message,), {
    'DESCRIPTOR' : _STATISTICS_BYHOSTENTRY,
    '__module__' : 'ui_pb2'
    # @@protoc_insertion_point(class_scope:protocol.Statistics.ByHostEntry)
    })
  ,

  'ByPortEntry' : _reflection.GeneratedProtocolMessageType('ByPortEntry', (_message.Message,), {
    'DESCRIPTOR' : _STATISTICS_BYPORTENTRY,
    '__module__' : 'ui_pb2'
    # @@protoc_insertion_point(class_scope:protocol.Statistics.ByPortEntry)
    })
  ,

  'ByUidEntry' : _reflection.GeneratedProtocolMessageType('ByUidEntry', (_message.Message,), {
    'DESCRIPTOR' : _STATISTICS_BYUIDENTRY,
    '__module__' : 'ui_pb2'
    # @@protoc_insertion_point(class_scope:protocol.Statistics.ByUidEntry)
    })
  ,

  'ByExecutableEntry' : _reflection.GeneratedProtocolMessageType('ByExecutableEntry', (_message.Message,), {
    'DESCRIPTOR' : _STATISTICS_BYEXECUTABLEENTRY,
    '__module__' : 'ui_pb2'
    # @@protoc_insertion_point(class_scope:protocol.Statistics.ByExecutableEntry)
    })
  ,
  'DESCRIPTOR' : _STATISTICS,
  '__module__' : 'ui_pb2'
  # @@protoc_insertion_point(class_scope:protocol.Statistics)
  })
_sym_db.RegisterMessage(Statistics)
_sym_db.RegisterMessage(Statistics.ByProtoEntry)
_sym_db.RegisterMessage(Statistics.ByAddressEntry)
_sym_db.RegisterMessage(Statistics.ByHostEntry)
_sym_db.RegisterMessage(Statistics.ByPortEntry)
_sym_db.RegisterMessage(Statistics.ByUidEntry)
_sym_db.RegisterMessage(Statistics.ByExecutableEntry)

PingRequest = _reflection.GeneratedProtocolMessageType('PingRequest', (_message.Message,), {
  'DESCRIPTOR' : _PINGREQUEST,
  '__module__' : 'ui_pb2'
  # @@protoc_insertion_point(class_scope:protocol.PingRequest)
  })
_sym_db.RegisterMessage(PingRequest)

PingReply = _reflection.GeneratedProtocolMessageType('PingReply', (_message.Message,), {
  'DESCRIPTOR' : _PINGREPLY,
  '__module__' : 'ui_pb2'
  # @@protoc_insertion_point(class_scope:protocol.PingReply)
  })
_sym_db.RegisterMessage(PingReply)

StringInt = _reflection.GeneratedProtocolMessageType('StringInt', (_message.Message,), {
  'DESCRIPTOR' : _STRINGINT,
  '__module__' : 'ui_pb2'
  # @@protoc_insertion_point(class_scope:protocol.StringInt)
  })
_sym_db.RegisterMessage(StringInt)

Process = _reflection.GeneratedProtocolMessageType('Process', (_message.Message,), {

  'EnvEntry' : _reflection.GeneratedProtocolMessageType('EnvEntry', (_message.Message,), {
    'DESCRIPTOR' : _PROCESS_ENVENTRY,
    '__module__' : 'ui_pb2'
    # @@protoc_insertion_point(class_scope:protocol.Process.EnvEntry)
    })
  ,

  'ChecksumsEntry' : _reflection.GeneratedProtocolMessageType('ChecksumsEntry', (_message.Message,), {
    'DESCRIPTOR' : _PROCESS_CHECKSUMSENTRY,
    '__module__' : 'ui_pb2'
    # @@protoc_insertion_point(class_scope:protocol.Process.ChecksumsEntry)
    })
  ,
  'DESCRIPTOR' : _PROCESS,
  '__module__' : 'ui_pb2'
  # @@protoc_insertion_point(class_scope:protocol.Process)
  })
_sym_db.RegisterMessage(Process)
_sym_db.RegisterMessage(Process.EnvEntry)
_sym_db.RegisterMessage(Process.ChecksumsEntry)

Connection = _reflection.GeneratedProtocolMessageType('Connection', (_message.Message,), {

  'ProcessEnvEntry' : _reflection.GeneratedProtocolMessageType('ProcessEnvEntry', (_message.Message,), {
    'DESCRIPTOR' : _CONNECTION_PROCESSENVENTRY,
    '__module__' : 'ui_pb2'
    # @@protoc_insertion_point(class_scope:protocol.Connection.ProcessEnvEntry)
    })
  ,

  'ProcessChecksumsEntry' : _reflection.GeneratedProtocolMessageType('ProcessChecksumsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CONNECTION_PROCESSCHECKSUMSENTRY,
    '__module__' : 'ui_pb2'
    # @@protoc_insertion_point(class_scope:protocol.Connection.ProcessChecksumsEntry)
    })
  ,
  'DESCRIPTOR' : _CONNECTION,
  '__module__' : 'ui_pb2'
  # @@protoc_insertion_point(class_scope:protocol.Connection)
  })
_sym_db.RegisterMessage(Connection)
_sym_db.RegisterMessage(Connection.ProcessEnvEntry)
_sym_db.RegisterMessage(Connection.ProcessChecksumsEntry)

Operator = _reflection.GeneratedProtocolMessageType('Operator', (_message.Message,), {
  'DESCRIPTOR' : _OPERATOR,
  '__module__' : 'ui_pb2'
  # @@protoc_insertion_point(class_scope:protocol.Operator)
  })
_sym_db.RegisterMessage(Operator)

Rule = _reflection.GeneratedProtocolMessageType('Rule', (_message.Message,), {
  'DESCRIPTOR' : _RULE,
  '__module__' : 'ui_pb2'
  # @@protoc_insertion_point(class_scope:protocol.Rule)
  })
_sym_db.RegisterMessage(Rule)

StatementValues = _reflection.GeneratedProtocolMessageType('StatementValues', (_message.Message,), {
  'DESCRIPTOR' : _STATEMENTVALUES,
  '__module__' : 'ui_pb2'
  # @@protoc_insertion_point(class_scope:protocol.StatementValues)
  })
_sym_db.RegisterMessage(StatementValues)

Statement = _reflection.GeneratedProtocolMessageType('Statement', (_message.Message,), {
  'DESCRIPTOR' : _STATEMENT,
  '__module__' : 'ui_pb2'
  # @@protoc_insertion_point(class_scope:protocol.Statement)
  })
_sym_db.RegisterMessage(Statement)

Expressions = _reflection.GeneratedProtocolMessageType('Expressions', (_message.Message,), {
  'DESCRIPTOR' : _EXPRESSIONS,
  '__module__' : 'ui_pb2'
  # @@protoc_insertion_point(class_scope:protocol.Expressions)
  })
_sym_db.RegisterMessage(Expressions)

FwRule = _reflection.GeneratedProtocolMessageType('FwRule', (_message.Message,), {
  'DESCRIPTOR' : _FWRULE,
  '__module__' : 'ui_pb2'
  # @@protoc_insertion_point(class_scope:protocol.FwRule)
  })
_sym_db.RegisterMessage(FwRule)

FwChain = _reflection.GeneratedProtocolMessageType('FwChain', (_message.Message,), {
  'DESCRIPTOR' : _FWCHAIN,
  '__module__' : 'ui_pb2'
  # @@protoc_insertion_point(class_scope:protocol.FwChain)
  })
_sym_db.RegisterMessage(FwChain)

FwChains = _reflection.GeneratedProtocolMessageType('FwChains', (_message.Message,), {
  'DESCRIPTOR' : _FWCHAINS,
  '__module__' : 'ui_pb2'
  # @@protoc_insertion_point(class_scope:protocol.FwChains)
  })
_sym_db.RegisterMessage(FwChains)

SysFirewall = _reflection.GeneratedProtocolMessageType('SysFirewall', (_message.Message,), {
  'DESCRIPTOR' : _SYSFIREWALL,
  '__module__' : 'ui_pb2'
  # @@protoc_insertion_point(class_scope:protocol.SysFirewall)
  })
_sym_db.RegisterMessage(SysFirewall)

ClientConfig = _reflection.GeneratedProtocolMessageType('ClientConfig', (_message.Message,), {
  'DESCRIPTOR' : _CLIENTCONFIG,
  '__module__' : 'ui_pb2'
  # @@protoc_insertion_point(class_scope:protocol.ClientConfig)
  })
_sym_db.RegisterMessage(ClientConfig)

Notification = _reflection.GeneratedProtocolMessageType('Notification', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFICATION,
  '__module__' : 'ui_pb2'
  # @@protoc_insertion_point(class_scope:protocol.Notification)
  })
_sym_db.RegisterMessage(Notification)

NotificationReply = _reflection.GeneratedProtocolMessageType('NotificationReply', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFICATIONREPLY,
  '__module__' : 'ui_pb2'
  # @@protoc_insertion_point(class_scope:protocol.NotificationReply)
  })
_sym_db.RegisterMessage(NotificationReply)


DESCRIPTOR._options = None
_STATISTICS_BYPROTOENTRY._options = None
_STATISTICS_BYADDRESSENTRY._options = None
_STATISTICS_BYHOSTENTRY._options = None
_STATISTICS_BYPORTENTRY._options = None
_STATISTICS_BYUIDENTRY._options = None
_STATISTICS_BYEXECUTABLEENTRY._options = None
_PROCESS_ENVENTRY._options = None
_PROCESS_CHECKSUMSENTRY._options = None
_CONNECTION_PROCESSENVENTRY._options = None
_CONNECTION_PROCESSCHECKSUMSENTRY._options = None

_UI = _descriptor.ServiceDescriptor(
  name='UI',
  full_name='protocol.UI',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=4477,
  serialized_end=4780,
  methods=[
  _descriptor.MethodDescriptor(
    name='Ping',
    full_name='protocol.UI.Ping',
    index=0,
    containing_service=None,
    input_type=_PINGREQUEST,
    output_type=_PINGREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='AskRule',
    full_name='protocol.UI.AskRule',
    index=1,
    containing_service=None,
    input_type=_CONNECTION,
    output_type=_RULE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Subscribe',
    full_name='protocol.UI.Subscribe',
    index=2,
    containing_service=None,
    input_type=_CLIENTCONFIG,
    output_type=_CLIENTCONFIG,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Notifications',
    full_name='protocol.UI.Notifications',
    index=3,
    containing_service=None,
    input_type=_NOTIFICATIONREPLY,
    output_type=_NOTIFICATION,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='PostAlert',
    full_name='protocol.UI.PostAlert',
    index=4,
    containing_service=None,
    input_type=_ALERT,
    output_type=_MSGRESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_UI)

DESCRIPTOR.services_by_name['UI'] = _UI

# @@protoc_insertion_point(module_scope)



#
# pytest -v tests/nodes.py
#

import json
from PyQt5 import QtCore
from opensnitch import ui_pb2
from opensnitch.config import Config
from opensnitch.nodes import Nodes
from tests.dialogs import ClientConfig

class NotifTest(QtCore.QObject):
    """We need to subclass from QObject in order to be able to user signals and slots.
    """
    signal = QtCore.pyqtSignal(ui_pb2.NotificationReply)

    @QtCore.pyqtSlot(ui_pb2.NotificationReply)
    def callback(self, reply):
        assert reply != None
        assert reply.code == ui_pb2.OK and reply.type == ui_pb2.LOAD_FIREWALL and reply.data == "test"


class TestNodes():

    @classmethod
    def setup_method(self):
        self.nid = None
        self.daemon_config = ClientConfig
        self.nodes = Nodes.instance()
        self.nodes._db.insert("nodes",
                              "(addr, status, hostname, daemon_version, daemon_uptime, " \
                              "daemon_rules, cons, cons_dropped, version, last_connection)",
                              (
                                  "1.2.3.4", Nodes.ONLINE, "xxx", "v1.2.3", str(0),
                                  "", "0", "0", "",
                                  "2022-01-03 11:22:48.101624"
                              )
                              )


    def test_add(self, qtbot):
        node = self.nodes.add("peer:1.2.3.4", self.daemon_config)

        assert node != None

    def test_get_node(self, qtbot):
        node = self.nodes.get_node("peer:1.2.3.4")

        assert node != None

    def test_get_addr(self, qtbot):
        proto, addr = self.nodes.get_addr("peer:1.2.3.4")

        assert proto == "peer" and addr == "1.2.3.4"

    def test_get_nodes(self, qtbot):
        nodes = self.nodes.get_nodes()
        print(nodes)

        assert nodes.get("peer:1.2.3.4") != None

    def test_add_rule(self, qtbot):
        self.nodes.add_rule(
            "2022-01-03 11:22:48.101624",
            "peer:1.2.3.4",
            "test",
            True,
            False,
            Config.ACTION_ALLOW, Config.DURATION_30s,
            Config.RULE_TYPE_SIMPLE, False, "dest.host", ""
        )

        query = self.nodes._db.get_rule("test", "peer:1.2.3.4")

        assert query.first() == True
        assert query.record().value(0) == "2022-01-03 11:22:48.101624"
        assert query.record().value(1) == "peer:1.2.3.4"
        assert query.record().value(2) == "test"
        assert query.record().value(3) == "1"
        assert query.record().value(4) == "0"
        assert query.record().value(5) == Config.ACTION_ALLOW
        assert query.record().value(6) == Config.DURATION_30s
        assert query.record().value(7) == Config.RULE_TYPE_SIMPLE
        assert query.record().value(8) == "0"
        assert query.record().value(9) == "dest.host"

    def test_update_rule_time(self, qtbot):
        query = self.nodes._db.get_rule("test", "peer:1.2.3.4")
        assert query.first() == True
        assert query.record().value(0) == "2022-01-03 11:22:48.101624"

        self.nodes.update_rule_time("2022-01-03 21:22:48.101624", "test", "peer:1.2.3.4")
        query = self.nodes._db.get_rule("test", "peer:1.2.3.4")
        assert query.first() == True
        assert query.record().value(0) == "2022-01-03 21:22:48.101624"

    def test_delete_rule(self, qtbot):
        query = self.nodes._db.get_rule("test", "peer:1.2.3.4")
        assert query.first() == True

        self.nodes.delete_rule("test", "peer:1.2.3.4", None)
        query = self.nodes._db.get_rule("test", "peer:1.2.3.4")
        assert query.first() == False

    def test_update_node_status(self, qtbot):
        query = self.nodes._db.select("SELECT status FROM nodes WHERE addr = '{0}'".format("1.2.3.4"))
        assert query != None and query.exec_() == True and query.first() == True
        assert query.record().value(0) == Nodes.ONLINE

        self.nodes.update("peer", "1.2.3.4", Nodes.OFFLINE)
        query = self.nodes._db.select("SELECT status FROM nodes WHERE addr = '{0}'".format("1.2.3.4"))
        assert query != None and query.exec_() == True and query.first() == True
        assert query.record().value(0) == Nodes.OFFLINE

    def test_send_notification(self, qtbot):
        notifs = NotifTest()
        notifs.signal.connect(notifs.callback)

        test_notif = ui_pb2.Notification(
            clientName="",
            serverName="",
            type=ui_pb2.LOAD_FIREWALL,
            data="test",
            rules=[])

        self.nid = self.nodes.send_notification("peer:1.2.3.4", test_notif, notifs.signal)
        assert self.nodes._notifications_sent[self.nid] != None
        assert self.nodes._notifications_sent[self.nid]['type'] == ui_pb2.LOAD_FIREWALL

    def test_reply_notification(self, qtbot):
        reply_notif = ui_pb2.Notification(
            id = self.nid,
            clientName="",
            serverName="",
            type=ui_pb2.LOAD_FIREWALL,
            data="test",
            rules=[])
        # just after process the reply, the notification is deleted (except if
        # is of type MONITOR_PROCESS
        self.nodes.reply_notification("peer:1.2.3.4", reply_notif)
        assert self.nid not in self.nodes._notifications_sent

    def test_delete(self, qtbot):
        self.nodes.delete("peer:1.2.3.4")
        node = self.nodes.get_node("peer:1.2.3.4")
        nodes = self.nodes.get_nodes()

        assert node == None
        assert nodes.get("peer:1.2.3.4") == None




from .enums import *

import opensnitch.proto as proto
ui_pb2, ui_pb2_grpc = proto.import_()

class Expr():
    """
    Expr returns a new nftables expression that defines a match or an action:
        tcp dport 22, udp sport 53
        log prefix "xxx"

    Attributes:
        op (string): operator (==, !=, ...).
        what (string): name of the statement (tcp, udp, ip, ...)
        value (tuple): array of values (dport -> 22, etc).
    """
    @staticmethod
    def new(op, what, values):
        expr = ui_pb2.Expressions()
        expr.Statement.Op = op
        expr.Statement.Name = what

        for val in values:
            exprValues = ui_pb2.StatementValues()
            exprValues.Key = val[0]
            exprValues.Value = val[1]
            expr.Statement.Values.extend([exprValues])

        return expr

class ExprCt(Enums):
    STATE = "state"
    NEW = "new"
    ESTABLISHED = "established"
    RELATED = "related"
    INVALID = "invalid"
    SET = "set"
    MARK = "mark"

class ExprMeta(Enums):
    SET = "set"
    MARK = "mark"
    L4PROTO = "l4proto"
    SKUID = "skuid"
    SKGID = "skgid"
    PROTOCOL = "protocol"
    PRIORITY = "priority"

class ExprIface(Enums):
    IIFNAME = "iifname"
    OIFNAME = "oifname"

class ExprICMP(Enums):
    ECHO_REQUEST = "echo-request"
    ECHO_REPLY = "echo-reply"
    SOURCE_QUENCH = "source-quench"
    DEST_UNREACHABLE = "destination-unreachable"
    ROUTER_ADVERTISEMENT = "router-advertisement"
    ROUTER_SOLICITATION = "router-solicitation"
    REDIRECT = "redirect"
    TIME_EXCEEDED = "time-exceeded"
    INFO_REQUEST = "info-request"
    INFO_REPLY = "info-reply"
    PARAMETER_PROBLEM = "parameter-problem"
    TIMESTAMP_REQUEST = "timestamp-request"
    TIMESTAMP_REPLY = "timestamp-reply"
    ADDRESS_MASK_REQUEST = "address-mask-request"
    ADDRESS_MASK_REPLY = "address-mask-reply"

    # IPv6
    PACKET_TOO_BIG = "packet-too-big"
    NEIGHBOUR_SOLICITATION = "neighbour-solicitation"
    NEIGHBOUR_ADVERTISEMENT = "neighbour-advertisement"

class ExprICMPRejectCodes(Enums):
    NO_ROUTE = "no-route"
    PROT_UNREACHABLE = "prot-unreachable"
    PORT_UNREACHABLE = "port-unreachable"
    NET_UNREACHABLE = "net-unreachable"
    ADDR_UNREACHABLE = "addr-unreachable"
    HOST_UNREACHABLE = "host-unreachable"
    NET_PROHIBITED = "net-prohibited"
    HOST_PROHIBITED = "host-prohibited"
    ADMIN_PROHIBITED = "admin-prohibited"
    REJECT_ROUTE = "reject-route"
    REJECT_POLICY_FAIL = "policy-fail"

class ExprLog(Enums):
    LOG = "log"
    LEVEL = "level"
    PREFIX = "prefix"

class ExprLogLevels(Enums):
    EMERG = "emerg"
    ALERT = "alert"
    CRIT = "crit"
    ERR = "err"
    WARN = "warn"
    NOTICE = "notice"
    INFO = "info"
    DEBUG = "debug"
    AUDIT = "audit"

class ExprCounter(Enums):
    COUNTER = "counter"
    PACKETS = "packets"
    BYTES = "bytes"
    NAME = "name"

class ExprLimit(Enums):
    OVER = "over"
    LIMIT = "limit"
    UNITS = "units"
    RATE_UNITS = "rate-units"
    TIME_UNITS = "time-units"

class ExprQuota(Enums):
    QUOTA = "quota"
    OVER = "over"
    UNTIL = "until"
    USED = "used"
    UNIT = "unit"



from PyQt5.QtCore import Qt
from PyQt5.QtGui import QStandardItemModel
from opensnitch.customwidgets.generictableview import GenericTableModel
from opensnitch.utils import sockets

class NetstatTableModel(GenericTableModel):

    def __init__(self, tableName, headerLabels):
        super().__init__(tableName, headerLabels)

        self.COL_STATE =2
        self.COL_PROTO = 7
        self.COL_FAMILY = 10

    def data(self, index, role=Qt.DisplayRole):
        """Paint rows with the data stored in self.items"""
        if role == Qt.DisplayRole or role == Qt.EditRole:
            items_count = len(self.items)
            if index.isValid() and items_count > 0 and index.row() < items_count:
                try:
                    # FIXME: protocol UDP + state CLOSE == state LISTEN
                    if index.column() == self.COL_STATE:
                        return sockets.State[self.items[index.row()][index.column()]]
                    elif index.column() == self.COL_PROTO:
                        return sockets.Proto[self.items[index.row()][index.column()]]
                    elif index.column() == self.COL_FAMILY:
                        return sockets.Family[self.items[index.row()][index.column()]]
                    return self.items[index.row()][index.column()]
                except Exception as e:
                    print("[socketsmodel] exception:", e, index.row(), index.column())
        return QStandardItemModel.data(self, index, role)
